@@ -1,6 +1,6 @@
 from os import environ
 from os.path import isfile, join
-import getpass
+from os.path import expanduser
 import json
 import requests
 
@@ -16,7 +16,7 @@ class Refresh(Vault):
 
     def __init__(self, config_file=None, server_name="default"):
         Vault.__init__(self, config_file=config_file, server_name=server_name)
-        self.ssh_loc = "/Users/%s/.ssh" % getpass.getuser()
+        self.ssh_loc = expanduser("~/.ssh")
         self.key_name = self.__get_key_name()
         self.pubkey_path = "%s/%s.pub" % (self.ssh_loc, self.key_name)
         self.refresh_token = self.__get_refresh_token()
